# Changelog

## [0.1.5a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.1.5a1) (2024-10-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.1.4...0.1.5a1)

**Implemented enhancements:**

- Issue with language configuration selection in autoconfigure [\#243](https://github.com/OpenVoiceOS/OVOS-workshop/issues/243)

**Merged pull requests:**

- fix:handle misc files and folder names mixed with lang folder [\#246](https://github.com/OpenVoiceOS/OVOS-workshop/pull/246) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
